# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class JobKind(str, Enum):
    """
    JobKind
    """

    """
    allowed enum values
    """
    METRICS_CALCULATION = 'metrics_calculation'
    CONNECTOR_CHECK = 'connector_check'
    LIST_DATASETS = 'list_datasets'
    SCHEMA_INSPECTION = 'schema_inspection'
    FETCH_DATA = 'fetch_data'
    ALERT_CHECK = 'alert_check'
    SCHEDULE_JOBS = 'schedule_jobs'
    CREATE_MODEL_TASK = 'create_model_task'
    CREATE_MODEL_LINK_TASK = 'create_model_link_task'
    UPDATE_MODEL_TASK_RULES = 'update_model_task_rules'
    DELETE_MODEL_TASK = 'delete_model_task'
    FETCH_MODEL_TASK = 'fetch_model_task'
    REGENERATE_TASK_VALIDATION_KEY = 'regenerate_task_validation_key'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of JobKind from a JSON string"""
        return cls(json.loads(json_str))


