# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.custom_aggregation_version_spec_schema import CustomAggregationVersionSpecSchema
from typing import Optional, Set
from typing_extensions import Self

class CustomAggregationSpecSchema(BaseModel):
    """
    CustomAggregationSpecSchema
    """ # noqa: E501
    id: StrictStr = Field(description="Unique identifier of the custom aggregation with version.")
    name: StrictStr = Field(description="Name of the custom aggregation function.")
    description: Optional[StrictStr] = None
    workspace_id: StrictStr = Field(description="Unique identifier of the custom aggregation's parent workspace.")
    versions: List[CustomAggregationVersionSpecSchema] = Field(description="List of versions of the custom aggregation configuration.")
    latest_version: StrictInt = Field(description="Max/latest version of the custom aggregation that exists. This version may or may not be included in the list of versions depending on applied filters.")
    deleted_at: Optional[datetime] = None
    is_deleted: Optional[StrictBool] = Field(default=False, description="Flag indicating if the aggregation has been soft deleted.")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "workspace_id", "versions", "latest_version", "deleted_at", "is_deleted"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomAggregationSpecSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in versions (list)
        _items = []
        if self.versions:
            for _item_versions in self.versions:
                if _item_versions:
                    _items.append(_item_versions.to_dict())
            _dict['versions'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if deleted_at (nullable) is None
        # and model_fields_set contains the field
        if self.deleted_at is None and "deleted_at" in self.model_fields_set:
            _dict['deleted_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomAggregationSpecSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "workspace_id": obj.get("workspace_id"),
            "versions": [CustomAggregationVersionSpecSchema.from_dict(_item) for _item in obj["versions"]] if obj.get("versions") is not None else None,
            "latest_version": obj.get("latest_version"),
            "deleted_at": obj.get("deleted_at"),
            "is_deleted": obj.get("is_deleted") if obj.get("is_deleted") is not None else False
        })
        return _obj


